**************
pyftsetuptools
**************

This is a collection of ``setuptools`` extensions.





.. |date| date:: %Y-%m-%d %H:%M:%S %Z
.. footer::
    | Copyright © 2014 Lance Finn Helsten
    | Licensed under Apache License, Version 2.0.
    | Document generated: |date|.

